# MooCoderPy
Python/Tkinter version of Moocoder

Very much a work in progress, but it currently works as a simple Moo client ( server details will need to be modified in code.
Currently test1.py contains the startup code, but that will change over time.
